@@ -1,4 +1,4 @@
-# $Id: autogen.sh,v 1.3 2003/02/04 18:08:53 rousseau Exp $
+# $Id: autogen.sh,v 1.1.1.2 2004/07/20 16:30:34 rousseau Exp $
 
 set -x
 
@@ -7,7 +7,7 @@ aclocal
 
 libtoolize --force --copy
 
-autoheader2.50
+autoheader
 automake --add-missing --foreign
-autoconf2.50
+autoconf
 
